@@ -203,12 +203,12 @@ class DockerWorker(object):
         tls_cacert = self.params.get('tls_cacert')
 
         if tls['verify']:
-            if tlscert:
-                self.check_file(tls['tls_cert'])
-                self.check_file(tls['tls_key'])
+            if tls_cert:
+                self.check_file(tls_cert)
+                self.check_file(tls_key)
                 tls['client_cert'] = (tls_cert, tls_key)
-            if tlscacert:
-                self.check_file(tls['tls_cacert'])
+            if tls_cacert:
+                self.check_file(tls_cacert)
                 tls['verify'] = tls_cacert
 
         return docker.tls.TLSConfig(**tls)
@@ -228,7 +228,10 @@ class DockerWorker(object):
     def check_image(self):
         find_image = ':'.join(self.parse_image())
         for image in self.dc.images():
-            for image_name in image['RepoTags']:
+            repo_tags = image.get('RepoTags')
+            if not repo_tags:
+                continue
+            for image_name in repo_tags:
                 if image_name == find_image:
                     return image
 
@@ -472,11 +475,16 @@ class DockerWorker(object):
             'volumes_from': self.params.get('volumes_from')
         }
 
-        if self.params.get('restart_policy') in ['on-failure', 'always']:
-            options['restart_policy'] = {
-                'Name': self.params.get('restart_policy'),
-                'MaximumRetryCount': self.params.get('restart_retries')
-            }
+        if self.params.get('restart_policy') in ['on-failure',
+                                                 'always',
+                                                 'unless-stopped']:
+            policy = {'Name': self.params.get('restart_policy')}
+            # NOTE(Jeffrey4l): MaximumRetryCount is only needed for on-failure
+            # policy
+            if self.params.get('restart_policy') == 'on-failure':
+                retries = self.params.get('restart_retries')
+                policy['MaximumRetryCount'] = retries
+            options['restart_policy'] = policy
 
         if binds:
             options['binds'] = binds
