@@ -7,6 +7,7 @@ export PATH="/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin"
 
 export KOLLA_BASE=$1
 export KOLLA_TYPE=$2
+export KEEPALIVED_VIRTUAL_ROUTER_ID=$(shuf -i 1-255 -n 1)
 
 function copy_logs {
     cp -rnL /var/lib/docker/volumes/kolla_logs/_data/* /tmp/logs/kolla/
@@ -25,6 +26,10 @@ function sanity_check {
     # Wait for service ready
     sleep 15
     source /etc/kolla/admin-openrc.sh
+    # TODO(Jeffrey4l): Restart the memcached container to cleanup all cache.
+    # Remove this after this bug is fixed
+    # https://bugs.launchpad.net/oslo.cache/+bug/1590779
+    docker restart memcached
     nova --debug service-list
     neutron --debug agent-list
     tools/init-runonce
@@ -58,6 +63,7 @@ function write_configs {
 kolla_base_distro: "${KOLLA_BASE}"
 kolla_install_type: "${KOLLA_TYPE}"
 kolla_internal_vip_address: "169.254.169.10"
+keepalived_virtual_router_id: "${KEEPALIVED_VIRTUAL_ROUTER_ID}"
 docker_restart_policy: "never"
 network_interface: "${PRIVATE_INTERFACE}"
 neutron_external_interface: "fake_interface"
@@ -69,6 +75,8 @@ EOF
     cat << EOF > /etc/kolla/config/nova/nova-compute.conf
 [libvirt]
 virt_type=qemu
+# NOTE(Jeffrey4l): fix the gate in iax-ord nodes for libvirt 2.0.
+cpu_mode=none
 EOF
 
     cat << EOF > /etc/kolla/config/nova.conf
