@@ -51,7 +51,7 @@ export PATH="/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin"
 echo 'deb http://apt.dockerproject.org/repo ubuntu-trusty main' | sudo tee /etc/apt/sources.list.d/docker.list
 add_key
 sudo apt-get update
-sudo apt-get install -y --no-install-recommends docker-engine btrfs-tools
+sudo apt-get install -y --no-install-recommends 'docker-engine=1.12.*' btrfs-tools
 
 sudo service docker stop
 setup_disk
